#
# spec file for package obs-scm-bridge
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?fedora} || 0%{?rhel}
%define build_pkg_name obs-build
%else
%define build_pkg_name build
%endif
Name:           obs-scm-bridge
Version:        0.6.3
Release:        1.1
Summary:        A help service to work with git repositories in OBS
License:        GPL-2.0-or-later
URL:            https://github.com/openSUSE/obs-scm-bridge
Source0:        %{name}-%{version}.tar.xz
Requires:       %{build_pkg_name} >= 20211125
Requires:       python3-PyYAML >= 6.0.0
# these are just recommends in build package, but we need it here
Requires:       perl(Date::Parse)
Requires:       perl(LWP::UserAgent)
Requires:       perl(Net::SSL)
Requires:       perl(Pod::Usage)
Requires:       perl(Time::Zone)
Requires:       perl(URI)
Requires:       perl(XML::Parser)
Requires:       perl(YAML::LibYAML)
Recommends:     python3-packaging
BuildArch:      noarch
%if 0%{?fedora} || 0%{?rhel}
Requires:       git
%else
Requires:       git-core
Requires:       git-lfs
%endif

%description

%prep
%autosetup

%build

%install
%make_install

%files
%{_prefix}/lib/obs/service

%changelog
* Tue May 13 2025 Adrian Schröter <adrian@suse.de>
- 0.6.3
  * Allow ssh:// scm urls as used by osc
  * project mode: avoid unecessary changes in package meta url
  * code cleanup
* Tue Mar 18 2025 Dirk Müller <dmueller@suse.com>
- fix dependency (it is python3-PyYAML)
* Fri Mar 14 2025 Adrian Schröter <adrian@suse.de>
- fix missing dependency to PyYAML
* Thu Feb 20 2025 Adrian Schröter <adrian@suse.de>
- 0.6.2
  * Make project mode always look for _config in the top dir, also
    when using subdirs.
* Mon Feb  3 2025 Adrian Schröter <adrian@suse.de>
- 0.6.1
  * new noobsinfo query parameter
    (can be used to hide git informations in sources, binaries
    won't contain them either then).
* Tue Jan 28 2025 Adrian Schröter <adrian@suse.de>
- 0.6.0
  * project mode: switching to to track package sources using
    git sha sums instead of md5sum via download_assets
* Wed Dec  4 2024 Adrian Schröter <adrian@suse.de>
- 0.5.4
  * fixed support of subdir parameter usage on project level
  * Fix handling of projectscmsync in the package xml writers
* Fri Nov 29 2024 Adrian Schröter <adrian@suse.de>
- 0.5.3
  * Switch to ssh url when using the bridge via osc
* Thu Nov 14 2024 Adrian Schröter <adrian@suse.de>
- 0.5.2
  * Don't overwrite files from git, but complain instead with
    an error. For example _scmsync.obsinfo file must not be part
    of the git tree. boo#1230469 CVE-2024-22038
* Wed Oct 30 2024 Adrian Schröter <adrian@suse.de>
- 0.5.1
  * Don't generate _scmsync.obsinfo outside of OBS source server
    import use case (eg. no more for osc co)
  * Enforce python 3.11 requirement
  * Fix export of _scmsync.obsinfo in project mode
  * Fix submodule detection
  * EXPERIMENTAL: support multiple package subdirs via _subdirs
    file. This syntax will change!
    (not documented on purpose therefore atm)
  * Using git credential manager
  * Report some errors as transient, so that OBS can re-try
* Tue May  7 2024 Adrian Schröter <adrian@suse.de>
- 0.5.0
  project mode related enhancements:
  * no more defining of bcntsynctag. We need to move this to package
    spec files to avoid to have these always defined.
  * QA hook to limit building a defined set of packages only
* Tue Apr 23 2024 Adrian Schröter <adrian@suse.de>
- 0.4.3
  * support SHA256 submodules
  * minor improvements
* Wed Oct 18 2023 Dirk Müller <dmueller@suse.com>
- readd git-lfs dependency
* Fri Jun  2 2023 Adrian Schröter <adrian@suse.de>
- update to 0.4.2
  * various fixes to handle additional git meta informations right
* Tue May 16 2023 Adrian Schröter <adrian@suse.de>
- update to 0.4.0
  * avoid export of .gitattributes file by default
  * upstream osc is supported now
  * export meta information of the git clone
  * Add fallback code for a specific case
  * Convert local links into symlinks in project git
* Thu Jan 26 2023 Adrian Schröter <adrian@suse.de>
- update to 0.3.0
  * optimize cloning when combining subdir parameter
  * solve release number handling when using multiple spec files
  * Require git-lfs to be always present and allow to opt out of lfs fetching
  * support local symlinks to git submodules
  * support recursive submodule cloning
  * Fix the scmsync entry for relative submodule urls
* Tue Nov  8 2022 Adrian Schröter <adrian@suse.de>
- update to 0.2.1
  * fixed loss of branch informations in packages in project mode
* Wed Jun  8 2022 Adrian Schröter <adrian@suse.de>
- update to version 0.2
  * no shallow clone when used with osc
  * support for LFS fetch
  * bugfixes (_config file export and path handling)
* Thu Feb 17 2022 Adrian Schröter <adrian@suse.de>
- initial release of version 0.1
